import logging
from httpclient import HttpRequest
from httpmessagehandler import HttpMessageHandler

from . import KongRequest, LambdaResponse

logger = logging.getLogger()


class KongLambdaMessageHandler(object):
    def __init__(self, http_message_handler):
        # type: (HttpMessageHandler) -> None
        self.http_message_handler = http_message_handler

    def handle_messages(self, event):
        # type: (dict) -> LambdaResponse
        request = KongRequest(event)

        http_request = HttpRequest(request.path, request.method, request.args, request.headers,
                                   request.data)
        http_response = self.http_message_handler.handle_request(http_request)
        response = LambdaResponse(status=http_response.status_code,
                                  response=http_response.body,
                                  headers=http_response.headers)
        return response.response



from setuptools import setup, find_packages
setup(
      name="KongLambdaMessageHandler",
      version="1.0.0",
      packages=find_packages(where="."),
      install_requires=['HttpMessageHandler==1.0.0'],
      url="https://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br"
)



from typing import Dict


class KongRequest(object):
    def __init__(self,
                 event: Dict):
        self.path = str(event['request_uri']).split('?')[0]
        self.method = event['request_method']
        self.args = event['request_uri_args']
        self.headers = event['request_headers']
        if 'request_body' in event:
            self.data = event['request_body'].encode("utf-8")
        else:
            self.data = ""
